@@ -36,14 +36,10 @@
 """
 
 from abc import ABC, abstractmethod
-from typing import Optional
+from typing import Optional, List
 
-from dimp import ID, ANYONE, EVERYONE, ANYWHERE
+from dimp import ID, ANYONE, EVERYONE, FOUNDER
 
-#
-#   Founder
-#
-founder = ID.create(name='moky', address=ANYWHERE)
 #
 #   Reserved names
 #
@@ -55,7 +51,8 @@ keywords = [
     # --------------------------------
     "crypto", "key", "symmetric", "asymmetric",
     "public", "private", "secret", "password",
-    "id", "address", "meta", "profile",
+    "id", "address", "meta",
+    "tai", "document", "profile", "visa", "bulletin",
     "entity", "user", "group", "contact",
     # --------------------------------
     "member", "admin", "administrator", "assistant",
@@ -93,14 +90,14 @@ class AddressNameService(ABC):
             'everyone': EVERYONE,
             'anyone': ANYONE,
             'owner': ANYONE,
-            'founder': founder,
+            'founder': FOUNDER,
         }
 
     @staticmethod
     def is_reserved(name: str) -> bool:
         return name in keywords
 
-    def cache(self, name: str, identifier: ID=None) -> bool:
+    def cache(self, name: str, identifier: ID = None) -> bool:
         if self.is_reserved(name):
             # this name is reserved, cannot register
             return False
@@ -114,7 +111,7 @@ class AddressNameService(ABC):
         """ Get ID by short name """
         return self.__caches.get(name)
 
-    def names(self, identifier: ID) -> Optional[list]:
+    def names(self, identifier: ID) -> Optional[List[str]]:
         """ Get all short names with the same ID """
         array = []
         for (key, value) in self.__caches.items():
@@ -123,7 +120,7 @@ class AddressNameService(ABC):
         return array
 
     @abstractmethod
-    def save(self, name: str, identifier: ID=None) -> bool:
+    def save(self, name: str, identifier: ID = None) -> bool:
         """
         Save ANS record
 
